<?php
/*
 * Tutorial: How to Limit the Number of Revisions Kept for a Post in WordPress
 * URL: https://www.rafaelcardero.com/tutorials/how-to-limit-the-number-of-revisions-kept-for-a-post-in-wordpress/
 */

/* -----------------------------------------------------------------------------
 * - Method 1
 * ---------------------------------------------------------------------------*/

/*
 * Sets the number of revisions to keep for the post types Post and Page.
 */
function ns_limit_revisions($num, $post){
    
    $N = 5; // Keep only the latest N revisions    
    $target_types = array('post', 'page');
    $is_target_type = in_array($post->post_type, $target_types);
    return $is_target_type ? $N : $num;
}
add_filter('wp_revisions_to_keep', 'ns_limit_revisions', 10, 2);

/* -----------------------------------------------------------------------------
 * - Method 2
 * ---------------------------------------------------------------------------*/

// Keep a maximum of five revisions
// define('WP_POST_REVISIONS', 5); // Place this line in the file wp-config.php

/* -----------------------------------------------------------------------------
 * - Exercise
 * ---------------------------------------------------------------------------*/

/*
 * Sets the number of revisions to keep for a post.
 */
function ns_set_revisions($num, $post){
    
    if($post->post_type == 'post'){
        return 7;
    }
    if($post->post_type == 'page'){
        return 5;
    }
    return 0;
}
add_filter('wp_revisions_to_keep', 'ns_set_revisions', 10, 2);